@@ -13,7 +13,7 @@ use POSIX qw( setsid _exit );
 
 @ISA = ('Exporter');
 @EXPORT_OK  = qw( cache_dir );
-$VERSION = "1.27";
+$VERSION = "1.28";
 
 %EXTANT_DIR = ();
 
@@ -238,16 +238,18 @@ sub cache_dir {
     }
     return $self->{full_path};
   } else {
-    opendir(DIR, $ttl_dir);
-    while (my $sub_dir = readdir(DIR)) {
-      next if($sub_dir =~ /^\.\.?$/);
-      next if($sub_dir =~ /$self->{cleanup_suffix}/);
-      $sub_dir = $1 if $sub_dir =~ /(.+)/;
-      if($self->expired_check($sub_dir)) {
-        $self->perhaps_cleanup("$ttl_dir$sub_dir");
+    if( rand(100) >= $self->{cleanup_frequency}) {
+      opendir(DIR, $ttl_dir);
+      while (my $sub_dir = readdir(DIR)) {
+        next if($sub_dir =~ /^\.\.?$/);
+        next if($sub_dir =~ /$self->{cleanup_suffix}/);
+        $sub_dir = $1 if $sub_dir =~ /(.+)/;
+        if($self->expired_check($sub_dir)) {
+          $self->perhaps_cleanup("$ttl_dir$sub_dir");
+        }
       }
+      closedir(DIR);
     }
-    closedir(DIR);
     $self->sub_mkdir($self->{full_dir});
     die "couldn't mkpath '$self->{full_dir}': $!" unless($self->dash_d($self->{full_dir}));
     $self->{full_path} = "$self->{full_dir}$self->{filename}";
@@ -416,7 +418,7 @@ __END__
 =head1 NAME
 
 File::CacheDir - Perl module to aid in keeping track and cleaning up files, quickly and without a cron
-$Id: CacheDir.pm,v 1.19 2004/06/15 06:42:54 earl Exp $
+$Id: CacheDir.pm,v 1.20 2005/01/06 09:44:27 earl Exp $
 
 =head1 DESCRIPTION
 
